@@ -1,22 +1,14 @@
-import tahrir_api.model as m
-
-import hashlib
-import os
+import logging
 import shutil
 import tempfile
-from datetime import (
-    datetime,
-    timedelta,
-)
 
-import logging
 log = logging.getLogger(__name__)
 
 
 def scale_to_standard_size(filename):
     try:
         import magickwand.image as magick
-    except Exception, e:
+    except Exception as e:
         log.warn(str(e))
         log.warn("Did not scale image to standard size")
         return
@@ -29,7 +21,7 @@ def scale_to_standard_size(filename):
 
     img.crop((s, s), (wo, ho))
     img.thumbnail(256)
-    handle, tempname = tempfile.mkstemp(suffix='.png')
+    handle, tempname = tempfile.mkstemp(suffix=".png")
     img.save(tempname)
-    shutil.move(filename, filename + '.original')
+    shutil.move(filename, filename + ".original")
     shutil.move(tempname, filename)
